PRO ecomap, inputYear, inputDay, inputTime, EcoHDFFileName, GeoFileName, OrigEcoMapFile

; IDL routine
;
; ecomap.pro v 0.5
;
; ecoMap.pro will create a pixel-level ecosystem map for a granule, as created 
;   when running the MOD06OD code.  This map is generated by reading in the 
;   geolocation arrays from an HDF file, and for each geolocated point,
;   finding the nearest neighbor from the ecosystem ancillary file.  This map
;   is outputted into a new HDF file, along with the geolocation arrays, and
;   a plot is produced showing the geolocated ecosystem map.
;
;
; Input: 
;    inputYear		String	   : The 4 digit year.
;    inputDay           String     : The 3 digit julian day.
;    inputTime          String     : The 4 digit time, HHMM.
;    EcoHDFFileName	String	   : Full path and name of the output HDF file.
;    GeoFileName	String	   : Full path and name of the file containing Geo info.
;    OrigEcoMapFile	String	   : Full path and name of the ecosystem ancillary file
; 
; Output:
;    		none
;
; Required routines:
;    ReadSDS
;    createecomap
;    outputecomap
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody and Mark Gray.
;  eric.moody@gsfc.nasa.gov
;  gray@climate.gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************

;


;*************************************************************************
;Read in the Lat Lons:
;*************************************************************************
GeoFileID = HDF_SD_START(GeoFileName,/READ)
LatArray = ReadSDS(GeoFileID,'Latitude',/scaleNo,/offsetNo)
LonArray = ReadSDS(GeoFileID,'Longitude',/scaleNo,/offsetNo)
HDF_SD_END, GeoFileID
help, LatArray
help, LonArray


;*************************************************************************
;Create the Ecosystem map from nearest neighbor point:
;*************************************************************************
EcosystemMap = createecomap(LatArray,LonArray,OrigEcoMapFile)


;*************************************************************************
;Output the ecosystem map to the HDF file:
;*************************************************************************
outputecomap, LatArray, LonArray, EcosystemMap, EcoHDFFileName, inputDay, inputYear, inputTime


END
