PRO eco

;*************************************************************************
; Name: eco
;
; Purpose:
;   This rountine is the main driver to plot a granule level IGBP ecosystem map.
;    Plotting variables are defined here and passed along to the plotting
;    routines.
;   Overall, this code reads in the granule's ecosystem map, generated in
;    the ecosystem mapping routine, and produces the ecosystem image.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:  Date of the granule being plotted.
;   Output_Path    :  Directory to store the image produced.
;   temp_HDF_Path  :  Directory where the ecosystem hdf map is stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;  plot_eco.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************



;*************************************************************************
; Define Year, Day, time:
;*************************************************************************
;Define the text strings to use:
year = GETENV('Year')
day  = GETENV('Day' )
time = GETENV('Time')

;*************************************************************************
; Define the output directory:
;*************************************************************************
output_dir = GETENV('Output_Path')

;*************************************************************************
; Define the file that contains the ecosystem information.
;*************************************************************************
;Read in the location of the temp HDF file from memory:
temp_HDF_path = GETENV('temp_HDF_path')
;Create the filenames array:
filename    = StrArr(1)
filename[0] = temp_HDF_path + 'Ecosystem.' + Year + '.' + Day + '.' + Time + '.hdf'

;*************************************************************************
; Provide the name of the output image file, for example:
;*************************************************************************
EcoOutFileName = output_dir+'EcoMap.'+Year+'.'+Day+'.'+Time+'.ps'


;*************************************************************************
;Add a title to the plot if desired. Ex. titlestring ='Title'
;*************************************************************************
titlestring = 'Ecosystem Map, Day '+Day+', '+Year+' '+Time+' UTC.'


;*************************************************************************
;If you would like to specify the lat/lons to plot, please specify them
;   here.  This option is to be used if you want to specify a lat/lon box
;   from the global map, or if you wish to specify the lat/lons of the 
;   granule(s) to plot.  The format is as follows:
;   limits=[NorthBound,WestBound,SouthBound,EastBound]
;If you want the program to compute the bounds, please set limits = 0
;*************************************************************************
;limits=[-10.,110.,-40.,160.]; Australia
;limits=[-43.0,4.0,-4.0,36.0]


;*************************************************************************
;Call the program, bearing in mind that only the postscript output is 
; available.  The basic call is as follows:
;*************************************************************************
;Define the sds_name for the ecosystem map:
sds_name = 'Ecosystem_Map'

;Call the plotting code:
plot_eco, filename, sds_name, EcoOutFileName, titlestring, /ps, /notation

END
