pro output_productmap,colorimage,range,xparameter,outputname,psdisplay=psdisplay,jpeg=jpeg,screen=screen,add=add,tiff=tiff,notation=notation

; IDL routine
;
;  output_productmap.pro v 0.5
;  
;    Outputs an 8-bit image to a jpeg or a ps file 
;
; v 0.5 notes: really needs work. I'd like to avoid using vector fonts in the jpeg output someday.  Image
;              sizing/location in the jpeg output is funny sometimes (xsize/ysize calculated from the 
;              display variables is sometimes wrong. Huh. wierd.) Notation in the ps output isn't always
;              located properly.
;              This code needs more abstraction and better documentation.
;              The option to output to the screen is not used yet.
;              This routine is really not 100% bug proof.  Yes well, even more so than the rest of the code.
;
; Keywords:
;    /psdisplay    output a ps files
;    /jpeg         output a jpeg file
;    /tiff         output a tiff file
;    /add          not currently used (development only)
;    /notation     turns on grids and continents
;    /screen       not implemented
;
; Input:
;
;    colorimage  byte array    3 channel byte image data of the form [n,m,3] where 3rd index is r,g,b
;    range       byte vector   channel max and mins
;    xparameter  real array    image positioning values for locating image in the display device
;    outputname  string        output file name for image
; Output:
;    none
;
; Required routines:  
;    finish_map.pro   draws some map grids and so forth on display device 
;
; Developer
;  v .5         Eric Moody moody@climate.gsfc.nasa.gov
;               Mark Gray mag@climate.gsfc.nasa.gov
;               SM&A - SSG
;               MODIS - Atmosphere Group

; Define the new color scheme for the ecosystem
;r=[255, 33,  0,  0,255,  0,255,  0,  0,  0,255,179,255, 77,255,239, 71,255,230,200]
;g=[ 50,255,239,  0, 15,138,204, 10,255,255,158,255,  0,255,255,251,158,126, 53,200]
;b=[  0,  0,251,153,255,255,  0,255,  0,168,255,  0,  0,  0,255,  0,255,  0, 58,200]
r=[255, 33,  0,  0,255,  0,255,  0,  0,255,255,179,255, 77,255,239, 71,255,230,200]
g=[ 50,255,239,  0, 15,138,204,  0,255,  0,255,255,  0,255,255,251,158,126, 53,200]
b=[  0,  0,251,153,255,255,  0,255,  0,  0,  0,  0,  0,  0,255,  0,255,  0, 58,200]
tvlct, r, g, b, 1

; Define the annotation for each color:
   allAnnote = ['Evrg. Needle Fr.','Evrg. Broad Fr.','Decd. Needle Fr.',$
                'Decd. Broad Fr.','Mixed Forest','Closed Shrubs',       $
                'Open/Shrubs','Woody Savanna','Savanna','Grassland',    $
                'Wetland','Cropland','Urban','Crop Mosaic',             $
                'Snow','Barren/Desert','Ocean Water',                   $
                'Tundra','Fresh Snow','Sea Ice'                         ]
   help, allAnnote
  
if  keyword_set(psdisplay) or keyword_set(screen) then begin
   xoffset = xparameter(0)
   yoffset = xparameter(1)
   xsize   = xparameter(2)
   ysize   = xparameter(3) 
   help, xoffset
   help, yoffset
   help, xsize
   help, ysize
   
   print,'max min colorimage',max(colorimage),min(colorimage)
   tv, colorimage, xoffset, yoffset, xsize = xsize, ysize = ysize
   finish_map,/ps
   ystart = 1.0 - float(!d.y_size - yoffset)/float(!d.y_size)
   yend   = 1.0 - float(!d.y_size - yoffset-ysize)/float(!d.y_size)

   ;colors = IndGen(20)+1
   sizey = yend-ystart
   print, 'size of colorbar',sizey

   ;Determine which ecosystems appear in the data:
   colortmp = intarr(20)
   annottmp = strarr(20)
   numcolors = 0
   for icnt = 1, 20 do begin
       dummyret = where(fix(colorimage) eq fix(icnt), count)
       print, 'icnt',icnt,'annote',allAnnote[icnt-1],'count',count
       if ( count gt 0 ) then begin
	  print, 'color',icnt,'count', count
          colortmp[numcolors] = icnt
          annottmp[numcolors] = allAnnote[icnt-1]
          numcolors = numcolors + 1
       endif
   endfor

   ;Set up the final colors and labels arrays:
   colors = intarr(numcolors)
   annote = strarr(numcolors)
   for jcnt = 0, numcolors-1 do begin
       colors[jcnt] = colortmp[jcnt]
       annote[jcnt] = annottmp[jcnt]
       print,'position',jcnt,colors[jcnt],annote[jcnt]
   endfor

   help, colors
   help, annote

   ;plot color bar
   color_key, colors = colors, labels = annote, xoff=3

endif
if keyword_set(psdisplay) then begin
  Device,/close
  set_plot,'x'
endif
if keyword_set(add) then begin
   print,'adding data'
   xoffset = xparameter(0)
   yoffset = xparameter(1)
   xsize = xparameter(2)
   ysize = xparameter(3)
   print,'writing output image data'
   tv, bytscl(colorimage,min=range[0],max=range[1]), xoffset, $
                yoffset, $
                xsize = xsize,  $
                ysize = ysize, $
                true=3          
endif

if keyword_set(jpeg) or keyword_set(tiff) then begin
  xoffset =fix(xparameter(0))
  yoffset =fix(xparameter(1))
  xsize = fix(xparameter(2))
  ysize = fix(xparameter(3))

;  xoffset=!d.x_size-(xoffset+ xsize+1)
;  yoffset=!d.y_size-(yoffset+ ysize+1)

  ;generate map and notation, write to z-buffer and read to image
  ; to  be combined with the colorimage

  ; read data from z-buffer and combine notation to form a single image
  if keyword_set(notation) then finish_map,/jpeg
 
  background=tvrd()
  background_pixels=where(background gt 0,backcount) 

  colorimage=bytscl(colorimage,min=range[0],max=range[1])

  arraytempsize=size(colorimage)
  newimage=bytarr(!d.x_size,!d.y_size)

; !!this is in the nature of a hack to make sure that the images sizes are consistent
; why they are sometimes not consistent escapes me right now.

  xsize=arraytempsize[1]-1
  ysize=arraytempsize[2]-1 

  newimage[xoffset:xoffset+xsize,yoffset:yoffset+ysize]=colorimage
  if backcount gt 0 then begin
     newimage[background_pixels]=background[background_pixels]
  endif
  if keyword_set(jpeg) then write_jpeg,outputname,newimage,quality=90
  if keyword_set(tiff) then  begin 

;  reorder array for tiff
;   tvlct,r,g,b,/get
   tiff_out=reverse(newimage,2)
   write_tiff,outputname,tiff_out,1,red=r,green=g,blue=b
;   write_tiff,outputname,tiff_out,1
  endif
endif

if keyword_set(screen) then begin

endif
end
