pro clm_ext_driver

;*************************************************************************
; Name: clm_ext_driver
;
; Purpose:
;   This routine will extract bit fields from the cloud mask, thus
;   creating pixel-level bit field maps for a granule.  The bit fields
;   are outputted into a new HDF file, along with the geolocation arrays.  The 
;   output hdf file is used as input to plot the bit fields.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:    Date of the granule being plotted.
;   Output_Path:        Directory to store the image produced.
;   temp_HDF_Path:      Directory where the bit field hdf file is stored.
;   Input_Path:         Directory where the MOD06 file is stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;   cloudmaskextracter.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
; it freely, subject to the following restrictions:
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;*************************************************************************
;Specify the year, day and time.
;*************************************************************************
year = GETENV('Year')
day  = GETENV('Day' )
time = GETENV('Time')


;*************************************************************************
;Specify the L2QA output file name and path:
;  Note:  Specify the full path
;*************************************************************************
; Read in the temp HDF path from environmental variables:
temp_HDF_path = GETENV('temp_HDF_path')
ClMaskHDFFileName = temp_HDF_path + 'CloudMaskTests.'+year+'.'+day+'.'+time+'.hdf'
print, ClMaskHDFFileName

;*************************************************************************
;Specify the path where the MOD06, cloud properties, file resides:
;  Note:  Specify the full path
;*************************************************************************
fullpath = GetENV('Input_Path')
file_spec = fullpath+'MOD06_*'+year+day+'.'+time+'*hdf'
result = FINDFILE(file_spec)
MODFileName = strcompress(result[0])
print, MODFileName


;*************************************************************************
;Specify the name of the Cloud Mask SDS:
;*************************************************************************
ClMaskSDSName = 'Cloud_Mask_1km'

;*************************************************************************
;Call the code:
;*************************************************************************
cloudmaskextracter, year, day, time, $
                    MODFileName, ClMaskHDFFileName, ClMaskSDSName


end
