PRO ir_extracter, inputyear, inputday, inputtime, $
                    MOD06FileName, L2QAHDFFileName

; IDL routine
;
; l2qa_extracter.pro v 0.5
;
; l2qa_Extracter.pro will retreive individual L2 QA test results
;   from the full byte QA arrays, in the MOD06 output file.  The test results
;   are written into an output HDF file, as seperate integer SDSs.
;
;
; Input: 
;    inputday		String	   : Julian Day
;    inputyear		String     : Year
;    inputtime		String	   : Time as HHMM (H=hour, M=minute)
;    MOD06FileName	String	   : The MOD06 granule filename.
;    L2QAHDFFileName	String 	   : The output L2QA filename.
; 
; Output:
;    		none
;
; Required routines:
;    ReadSDS
;    l2qa_bitextracter
;    outputl2qabits;
;
;*************************************************************************
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody and Mark Gray.
;  eric.moody@gsfc.nasa.gov
;  gray@climate.gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************
;


;*************************************************************************
;Read in the Lat Lons:
;*************************************************************************
MOD06FileID = HDF_SD_START(MOD06FileName,/READ)
LatArray = ReadSDS(MOD06FileID,'Latitude',/scaleNo,/offsetNo)
LonArray = ReadSDS(MOD06FileID,'Longitude',/scaleNo,/offsetNo)
HDF_SD_END, MOD06FileID


;*************************************************************************
;Extract the individual QA flags:
;*************************************************************************
QABitFlags = ir_bitextracter(MOD06FileName)


;*************************************************************************
;Output the QA flags and Lat/Lon to the HDF file:
;*************************************************************************
output_ir_flag, LatArray, LonArray,                $
                     QABitFlags, L2QAHDFFileName, $
                     inputDay, inputYear, inputTime


END
