pro GenerateRemappedImage,InputFile,DataType,sdsname,maxmin,InputXsize,InputYsize,starttile,endtile,tilesize,latitude,longitude,channels,tempoutputimage,xparameter,rescale,fileindex

; Why V2.0?
; This is a slightly complex routine.  Why all these looping gymnastics?  To save
; memory and make it possible to generate large images.  The v1.0 code plotted the
; individual pixels from the original arrays onto a remapped surface for the entire
; image and then 'dilated' the pixels to fill in the space between the pixels.
; For low resolution level2 products, or small highly magnified regions of level1b
; data the result is not optimal.  
;
;How does this all work?
;
; - the image data from the l1b file is processed in tiles that are 22 lines long and 
;   the full width of the scan (ie 1354 pixels for 1km MODIS, 768 pixels for MAS).
;
; - the tile processing is incremented so that the first and the last lines 
;   of the tiles over lap with the previous and subsequent tiles to produce
;   a seamless image whern all the tiles are combined.
; 
; - for each tile the image and corresponding latitude and longitude arrays 
;   are is rebined N times to produce interpolated larger versions of the tile.
;
; - These tiles are then remapped and the remapped pixels written 
;   to the output image array.
;
; - the output image array is passed out of the routine to be sent to an output
;   image format routine by the main code

;get lat long info and resize to the data resolution
GetLatLongArrays,datatype,InputXsize,InputYsize,InputFile,latitude,longitude

;get unique channels
UniqueChannels=channels(sort(channels))

UniqueChannels=UniqueChannels(uniq(UniqueChannels))

dummy=size(UniqueChannels)

if dummy[0] eq 1 then NumberofChannels=dummy[1]
if dummy[0] eq 0 then NumberofChannels=1

; final image size
ns = !d.x_size
nl = !d.y_size
if ( !d.flags and 1 ) then begin
  ns =1920L 
  nl = long( float( ns ) * float( !d.y_size ) / float( !d.x_size ) )
endif

for CurrentTile=StartTile, EndTile+1 do begin
   tilelineindex=(Currenttile)*tilesize
   print,'tile >',CurrentTile,' of ',Endtile+2

;  get the tile/s
   imagedata=fltarr(InputXSize,tilesize+1,NumberofChannels)
   for i=0,NumberofChannels-1 do begin
      dummytilesize=tilesize
      case 1 of
        datatype eq 'MODIS' : begin
          GetMODISdata,UniqueChannels[i],$
                   Inputfile,$
                   InputXSize,$
                   InputYSize,$
                   currenttile,$
                   tilesize,rescale,tilelineindex,i,$
                   imagedata_channel
        end
        datatype eq 'MAS' : begin
          GetMASdata,UniqueChannels[i],$
                   Inputfile,$
                   InputXSize,$
                   InputYSize,$
                   currenttile,$
                   tilesize,$
                   imagedata_channel
        end
        datatype eq 'LEVEL2' : begin
          GetLevel2Data,sdsname[i],$
                   Inputfile,$
                   InputXSize,$
                   InputYSize,$
                   currenttile,$
                   tilesize,rescale,tilelineindex,$
                   imagedata_channel
        end
      endcase
     
      if dummytilesize ne tilesize then imagedata=imagedata[*,0:tilesize,*]
      imagedata[*,*,i]=imagedata_channel
      imagedata_channel=0
   endfor

;  resize the tile data

   ScaleSize=2
   NewXSize=InputXSize*ScaleSize
   NewYSize=(tilesize+1)*ScaleSize
   ScaledImagedata=rebin(imagedata,NewXsize,NewYsize,NumberofChannels)

   imagedata=0

   LatitudeTile=rebin(latitude[*,tileLineIndex:tileLineIndex+tilesize],NewXsize,NewYsize) 
   LongitudeTile=rebin(longitude[*,tileLineIndex:tileLineIndex+tilesize],NewXsize,NewYsize)
;   LatitudeTile=(latitude[*,tileLineIndex:tileLineIndex+tilesize])
;   LongitudeTile=(longitude[*,tileLineIndex:tileLineIndex+tilesize])

;  remap the tile data to the image
   RemapTileData,ScaledImagedata,$
                 LatitudeTile,$
                 LongitudeTile,$
                 ns,nl,xparameter,$
                 UniqueChannels,$
                 maxmin,$
                 Channels,$
                 outputimage

  dummy=size(outputimage)
  if dummy[0] eq 2 and datatype eq 'LEVEL2' then begin
    newimage=bytarr(dummy[1],dummy[2],3)
    for i=0,2 do newimage[*,*,i]=outputimage
    outputimage=newimage
    ColorTableIndex=26
    Convert_To_CT,ColorTableIndex,outputimage
  endif
  if dummy[0] eq 2 and datatype ne 'LEVEL2' then begin
    newimage=bytarr(dummy[1],dummy[2],3)
    for i=0,2 do newimage[*,*,i]=outputimage
    outputimage=newimage
  endif

     
   if currenttile eq 0 and fileindex eq 0 then begin
      tempoutputimage=outputimage 
   endif else begin
      goodpixels=where(outputimage gt 0)

      if total(goodpixels) gt 0 then $
          tempoutputimage[goodpixels]=outputimage[goodpixels]
   endelse
   outputimage=0 

;  set some arrays to 0 to release memory
   outputimage=0
   ScaledImagedata=0
   LatitudeTile=0
   LongitudeTile=0
endfor

;dummy=size(tempoutputimage)
;if dummy[0] eq 2 then begin
;  newimage=bytarr(dummy[1],dummy[2],3)
;  for i=0,2 do newimage[*,*,i]=tempoutputimage
;  tempoutputimage=newimage
;  ColorTableIndex=26
;  Convert_To_CT,ColorTableIndex,tempoutputimage
;endif

end
