pro GetMODISmaxmin,channel,file,SDSXSize,SDSYSIZE,maxmin

;let's make sure we know what SDS names we need.

Visible250meter=['1','2']
Visible500meter=['3','4','5','6','7']
Reflective1km=['8','9','10','11','12','13','13hi','14','14hi','15','16','17','18','19','26']
Emissive1km=['20','21','22','23','24','25','27','28','29','30','31','32','33','34','35','36']
stringchannel=strcompress(string(channel),/remove_all)

case 1 of
;    MODIS 1km Dataset selected
     strpos(file,'MOD021KM') ge 0 : begin
       case 1 of 
          total(where(Visible250meter eq stringchannel)) ge 0. : begin
            varname='EV_250_Aggr1km_RefSB'
            index=where(Visible250meter eq stringchannel)
            localchannel=index[0]
          end
          total(where(Visible500meter eq stringchannel)) ge -0. : begin
            varname='EV_500_Aggr1km_RefSB'
            index=where(Visible500meter eq stringchannel)
            localchannel=index[0]
          end
          total(where(Reflective1km eq stringchannel)) ge 0. : begin
            varname='EV_1KM_RefSB'
            index=where(Reflective1km eq stringchannel)
            localchannel=index[0]
          end
          total(where(Emissive1km eq stringchannel)) ge 0. : begin
            varname='EV_1KM_Emissive'
            index=where(Emissive1km eq stringchannel)
            localchannel=index[0]
          end
       endcase
     end

;    MODIS 500m Dataset selected
     strpos(file,'MOD02HKM') ge 0 : begin
       case 1 of
          total(where(Visible250meter eq stringchannel)) ge 0. : begin
             varname='EV_250_Aggr500_RefSB'
             index=where(Visible250meter eq stringchannel)
             localchannel=index[0]
          end
          total(where(Visible500meter eq stringchannel)) ge 0. : begin
             varname='EV_500_RefSB'
             index=where(Visible500meter eq stringchannel)
             localchannel=index[0]
          end
       endcase
     end

;    MODIS 250m Dataset selected
     strpos(file,'MOD02QKM') ge 0 : begin
       if total(where(Visible250meter eq stringchannel)) ge 0. then begin
         varname='EV_250_RefSB'
         index=where(Visible250meter eq stringchannel)
         localchannel=index[0]
       endif
     end
endcase 
;Read SDS data
fileId = HDF_SD_START(file, /READ)

tilevector=[SDSXSize/10,SDSYSize/10,0]
startvector=[0,0,localchannel]
stridevector=[10,10,1]

index = HDF_SD_NAMETOINDEX(fileId, varname)
sdsid = HDF_SD_SELECT(fileId, index)
HDF_SD_GETDATA, sdsid, imagedata,count=tilevector,start=startvector,stride=stridevector
;find the names of the calibration parameters

if strpos(varname,'Emiss') ge 0 then begin
   scale_sds_name='radiance_scales'
   offset_sds_name='radiance_offsets'
endif else begin
   scale_sds_name='reflectance_scales'
   offset_sds_name='reflectance_offsets'
endelse

validrange_sds_name= 'valid_range'
fillvalue_sds_name= '_FillValue'

;get the calibration parameters
IF NOT Keyword_Set(scaleNo) THEN BEGIN
   scaleId = HDF_SD_ATTRFIND(sdsid,scale_sds_name)
   IF scaleId NE -1 THEN BEGIN
      HDF_SD_ATTRINFO, sdsid, scaleId, DATA=scale_factor
   ENDIF
ENDIF

IF NOT Keyword_Set(offsetNo) THEN BEGIN
   offsetId = HDF_SD_ATTRFIND(sdsid,offset_sds_name)
   IF offsetId NE -1 THEN BEGIN
      HDF_SD_ATTRINFO, sdsid, offsetId, DATA=offset
   ENDIF
ENDIF

IF NOT Keyword_Set(validrangeNo) THEN BEGIN
   validrangeId = HDF_SD_ATTRFIND(sdsid,validrange_sds_name)
   IF validrangeId NE -1 THEN BEGIN
      HDF_SD_ATTRINFO, sdsid, validrangeId, DATA=validrange
   ENDIF
ENDIF

IF NOT Keyword_Set(fillNo) THEN BEGIN
   fillId = HDF_SD_ATTRFIND(sdsid,fillvalue_sds_name)
   IF fillId NE -1 THEN BEGIN
      HDF_SD_ATTRINFO, sdsid, fillId, DATA=fillValue
   ENDIF
   fillvalue=fillvalue[0]
ENDIF

HDF_SD_ENDACCESS, sdsid
HDF_SD_END, fileId

index = Where(imagedata gt 35000, count)
imagedata = scale_factor[localchannel] * (imagedata-offset[localchannel])
allvalidrange=scale_factor[localchannel] * (validrange-offset[localchannel])
if count gt 0 then imagedata[index]=0.

maxmin=fltarr(2)
maxmin[0]=max(imagedata)
maxmin[1]=min(imagedata)
end
